import type { X509CreateCertificateOptions } from './X509ServiceOptions';
import type { AgentContext } from '../../agent';
import { Key } from '../../crypto/Key';
import { CredoWebCrypto } from '../../crypto/webcrypto';
type ExtensionObjectIdentifier = string;
type CanBeCritical<T> = T & {
    critical?: boolean;
};
type SubjectAlternativeNameExtension = CanBeCritical<{
    name: Array<{
        type: 'url' | 'dns';
        value: string;
    }>;
}>;
type AuthorityKeyIdentifierExtension = CanBeCritical<{
    keyId: string;
}>;
type SubjectKeyIdentifierExtension = CanBeCritical<{
    keyId: string;
}>;
type KeyUsageExtension = CanBeCritical<{
    usage: number;
}>;
type ExtendedKeyUsageExtension = CanBeCritical<{
    usage: Array<X509ExtendedKeyUsage>;
}>;
type ExtensionValues = SubjectAlternativeNameExtension | AuthorityKeyIdentifierExtension | SubjectKeyIdentifierExtension | KeyUsageExtension | ExtendedKeyUsageExtension;
type Extension = Record<ExtensionObjectIdentifier, ExtensionValues>;
export declare enum X509KeyUsage {
    DigitalSignature = 1,
    NonRepudiation = 2,
    KeyEncipherment = 4,
    DataEncipherment = 8,
    KeyAgreement = 16,
    KeyCertSign = 32,
    CrlSign = 64,
    EncipherOnly = 128,
    DecipherOnly = 256
}
export declare enum X509ExtendedKeyUsage {
    ServerAuth = "1.3.6.1.5.5.7.3.1",
    ClientAuth = "1.3.6.1.5.5.7.3.2",
    CodeSigning = "1.3.6.1.5.5.7.3.3",
    EmailProtection = "1.3.6.1.5.5.7.3.4",
    TimeStamping = "1.3.6.1.5.5.7.3.8",
    OcspSigning = "1.3.6.1.5.5.7.3.9",
    MdlDs = "1.0.18013.5.1.2"
}
export type X509CertificateOptions = {
    publicKey: Key;
    privateKey?: Uint8Array;
    extensions?: Array<Extension>;
    rawCertificate: Uint8Array;
};
export declare class X509Certificate {
    publicKey: Key;
    privateKey?: Uint8Array;
    extensions?: Array<Extension>;
    readonly rawCertificate: Uint8Array;
    constructor(options: X509CertificateOptions);
    static fromRawCertificate(rawCertificate: Uint8Array): X509Certificate;
    static fromEncodedCertificate(encodedCertificate: string): X509Certificate;
    private static parseCertificate;
    private getMatchingExtensions;
    get sanDnsNames(): string[];
    get sanUriNames(): string[];
    get authorityKeyIdentifier(): string | undefined;
    get subjectKeyIdentifier(): string | undefined;
    get keyUsage(): Array<X509KeyUsage>;
    get extendedKeyUsage(): Array<X509ExtendedKeyUsage> | undefined;
    isExtensionCritical(id: string): boolean;
    static create(options: X509CreateCertificateOptions, webCrypto: CredoWebCrypto): Promise<X509Certificate>;
    get subject(): string;
    get issuer(): string;
    verify({ verificationDate, publicKey }: {
        verificationDate: Date;
        publicKey?: Key;
    }, webCrypto: CredoWebCrypto): Promise<void>;
    /**
     * Get the thumprint of the X509 certificate in hex format.
     */
    getThumprintInHex(agentContext: AgentContext): Promise<string>;
    /**
     * Get the data elements of the x509 certificate
     */
    get data(): {
        issuerName: string;
        issuer: string;
        subjectName: string;
        subject: string;
        serialNumber: string;
        pem: string;
        notBefore: Date;
        notAfter: Date;
    };
    getIssuerNameField(field: string): string[];
    toString(format: 'asn' | 'pem' | 'hex' | 'base64' | 'text' | 'base64url'): string;
    equal(certificate: X509Certificate): boolean;
}
export {};
